.. include:: ../BADGES.rst
Usage
=====

Just run "swmmtoolbox --help" from a command line to get a list of subcommands::

    swmmtoolbox --help

.. program-output:: swmmtoolbox --help

Sub-command Detail
''''''''''''''''''

extract
~~~~~~~
.. program-output:: swmmtoolbox extract --help

list
~~~~
.. program-output:: swmmtoolbox catalog --help

listdetail
~~~~~~~~~~
.. program-output:: swmmtoolbox listdetail --help

listvariables
~~~~~~~~~~~~~
.. program-output:: swmmtoolbox listvariables --help

stdtoswmm5
~~~~~~~~~~
.. program-output:: swmmtoolbox stdtoswmm5 --help
